\NeedsTeXFormat{LaTeX2e}
\ProvidesClass{qccurj}[2020/01/01]
\typeout{Queensborough Community College Undergraduate Research Journal}
\LoadClass[12pt,letterpaper]{article}

\newif\ifBlind
\Blindfalse
\newif\ifDraft
\Draftfalse
\overfullrule=0pt
\DeclareOption{draft}{
  \PassOptionsToClass{draft}{article}
  \Drafttrue
  \overfullrule=5pt
}

\DeclareOption{blind}{
  \Blindtrue
}

\ProcessOptions
\RequirePackage{mathptmx}                %% Times New Roman font, both text and math
\RequirePackage[margin=1in]{geometry}    %% Page layout
\RequirePackage{xspace}                  %% Spacing
\RequirePackage{cite}                    %% Custom citation style; for Vancouver with parenthesis
\RequirePackage{amsmath,amssymb,amsthm}  %% Math: symbols and Theorems
\RequirePackage{hyperref}                %% Hyperlinks; required for url field in bibliography

%% Structure styling

%%% (Sub)pragraphs style (the rest is default)
\newcommand{\maybe@addperiod}[1]{#1\@addpunct{.}}
\renewcommand\paragraph{\@startsection{paragraph}{4}{\z@}{3.25ex \@plus1ex \@minus.2ex}{-1em}{%
\normalfont\normalsize\bfseries\maybe@addperiod}}
\renewcommand\subparagraph{\@startsection{subparagraph}{5}{\parindent}{3.25ex \@plus1ex \@minus .2ex}{-1em}{%
\normalfont\normalsize\itshape\maybe@addperiod}}

%%% Caption: label in bold.
\long\def\@makecaption#1#2{%
  \vskip\abovecaptionskip
  \sbox\@tempboxa{\textbf{#1}. #2}%
  \ifdim \wd\@tempboxa >\hsize
    \textbf{#1}. #2\par
  \else
    \global \@minipagefalse
    \hb@xt@\hsize{\hfil\box\@tempboxa\hfil}%
  \fi
  \vskip\belowcaptionskip}


%% Citation

%%% Styling
\renewcommand\citeleft{(}
\renewcommand\citeright{)}
\renewcommand\@biblabel[1]{(#1)} % from [1] to 1
\bibliographystyle{vancouver}

%%% Citation in blind mode
\let\oldbib\bibliography
\ifBlind%
\newwrite\dummy@reference@list
\immediate\openout\dummy@reference@list=\jobname.blindedrefs.bib
\fi
\newcommand{\@dummyreference}[1]{%
\ifBlind%
  \immediate\write\dummy@reference@list{%
    @misc{#1,title = {Reference concealed for double-blind review},year = {will appear on final version},}}%
\fi%
}
\renewcommand{\bibliography}[1]{\oldbib{\ifBlind \jobname.blindedrefs,\fi#1}}
\newcommand{\@blindcite@withopt}[2][]{\@dummyreference{#2}\cite[#1]{#2}}
\newcommand{\@blindcite@noopt}[1]{\@dummyreference{#1}\cite{#1}}
\newcommand{\blindcite}{\@ifnextchar [{\@blindcite@withopt}{\@blindcite@noopt}}
\newcommand{\blindnocite}[1]{\@dummyreference{#1}\nocite{#1}}


%% Theorems etc
\theoremstyle{plain}
\newtheorem{theorem}{Theorem}
\newtheorem{lemma}[theorem]{Lemma}
\newtheorem{proposition}[theorem]{Proposition}
%\newtheorem{scholia}[theorem]{Scholia}
\newtheorem{corollary}[theorem]{Corollary}
\newtheorem{claim}[theorem]{Claim}
\newtheorem{conjecture}[theorem]{Conjecture}

\theoremstyle{definition}
\newtheorem{definition}{Definition}

\newtheorem{example}{Example}
\newtheorem{remark}{Remark}

\let\@oldProofname\proofname
\renewcommand{\proofname}{\@oldProofname\xspace}

%% Title, authors, institution...
%\newcounter{@authorsCount}
%\newif\ifIn@AuthorMacro
%\In@AuthorMacrofalse
%\newcommand{\inst}[1]{%
%\ifcsname @institution\endcsname\relax\else\\\@for\tmp:=#1\do{\large\tmp\\}\\[-1em]\fi%
%%\expandafter\def\csname @institution@author@\the@authorsCount\endcsname{#1}%
%}

\newif\if@inst@defined
\@inst@definedfalse
\newcommand{\inst}[1]{%
  \global\@inst@definedtrue%
\ifcsname @institution\endcsname\relax%
\else%
  \\\large\setlength{\tabcolsep}{0pt}\begin{tabular}[t]{c}#1\end{tabular}%
\fi%
}

\def\and{%                  % \begin{tabular}
  \end{tabular}%
%  \ifIn@AuthorMacro\stepcounter{@authorsCount}\fi
  \hskip 1em \@plus.17fil%
  \begin{tabular}[t]{c}}%   % \end{tabular}

\def\@institution@nooverride{\relax}
\def\@institution@nostar#1{%
  \global\@inst@definedtrue%
  \if\@institution@nooverride\relax%
    \relax%
  \else%
    \@latex@warning@no@line{%
      Command \noexpand\institution overriding a previous \noexpand\institution* command}%
  \fi%
  \gdef\@institution{#1}}
\def\@institution@star#1{%
  \global\@inst@definedtrue%
  \ifcsname @institution\endcsname{%
    \@latex@warning@no@line{%
      Command \noexpand\institution* overridden by a previous \noexpand\institution command}%
  }\fi
  \gdef\@institution@nooverride{#1}}
\def\institution{\@ifstar\@institution@star\@institution@nostar}

\def\thanks#1{\footnotemark
  \protected@xdef\@thanks{\@thanks
    \protect\footnotetext[\the\c@footnote]{%
      \ifBlind Acknowledgments hidden for double-blind review.\else#1\fi}}%
}

\def\@maketitle{%
  \newpage
%  \null
%  \vskip 2em%
  \begin{center}%
  \let \footnote \thanks
    {\LARGE \@title \par}%
    \vskip 1.5em%
    \ifBlind
      \framebox{\parbox{5in}{\centering ~\\[1.5em]%
          \em Authors' names and affiliations hidden for double-blind review.\\[0.75em]~}}
    \else
      {\Large
        \lineskip .5em%
        \begin{tabular}[t]{c}%
%          \In@AuthorMacrotrue\@author\In@AuthorMacrofalse
           \@author
        \end{tabular}\par}%
      \ifcsname @institution\endcsname{\large
        \lineskip .5em%
        \begin{tabular}[t]{c}%
          \@institution
        \end{tabular}\par}\else
      \if\@institution@nooverride\relax{\relax}\else{\large
        \lineskip .5em%
        \begin{tabular}[t]{c}%
          \@institution@nooverride
        \end{tabular}\par}\fi\fi%
    \fi
    \ifDraft\vskip 1em%
    {\large \emph{Draft compiled on \@date}}\fi%
  \end{center}%
  \par
  \vskip 0.5em%
  \if@inst@defined\relax\else\@latex@warning@no@line{%
    No institution given; use \noexpand\inst, \noexpand\institution, or \noexpand\institution*.}\fi%
}

\AtBeginDocument{%
\maketitle\thispagestyle{plain}%
}

%% Blinding
\newcommand{\altblind}[2]{\ifBlind #2\else #1\fi}